@@ -145,6 +145,7 @@ from kivy.properties import (
 from kivy.uix.behaviors import ButtonBehavior, ToggleButtonBehavior                                     # type: ignore
 from kivy.uix.floatlayout import FloatLayout                                                            # type: ignore
 from kivy.uix.image import Image                                                                        # type: ignore
+from kivy.uix.relativelayout import RelativeLayout                                                      # type: ignore
 from kivy.uix.scrollview import ScrollView                                                              # type: ignore
 from kivy.uix.textinput import TextInput                                                                # type: ignore
 from kivy.uix.widget import Widget                                                                      # type: ignore
@@ -152,19 +153,170 @@ from kivy.uix.widget import Widget
 from ae.base import snake_to_camel                                                                      # type: ignore
 from ae.inspector import try_eval                                                                       # type: ignore
 from ae.gui_help import (                                                                               # type: ignore
-    anchor_points, help_id_tour_class, HelpAppBase, OnboardingTour, TourBase, REGISTERED_TOURS)
+    anchor_layout_x, anchor_layout_y, anchor_points, anchor_spec, help_id_tour_class,
+    HelpAppBase, OnboardingTour, TourBase, REGISTERED_TOURS)
 from ae.kivy_glsl import ShaderIdType, ShadersMixin                                                     # type: ignore
 from ae.kivy_relief_canvas import ReliefCanvas                                                          # type: ignore
 
 
-__version__ = '0.2.29'
+__version__ = '0.2.30'
 
 
 # load/declared help/tour widgets, based-on Kivy core widgets (without any features from ae.kivy_app/widgets.kv)
 Builder.load_file(os.path.join(os.path.dirname(__file__), "widgets.kv"))
 
 
-class ModalBehavior:                                                                    # pragma: no cover
+PosSizeCallable = Callable[[Widget, List[float]], Any]
+BoundWidgetPropertyId = Tuple[Widget, str, int]
+PropagatedAttributes = Tuple[Any, str, Optional[PosSizeCallable]]
+
+
+class AbsolutePosSizeBinder:
+    """ propagate widget(s) `pos`/`size` changes to attributes/callback, providing absolute window coordinates. """
+    def __init__(self, *widgets: Widget, bind_window_size: bool = False):
+        """ instantiate binder specifying the monitored widget(s).
+
+        :param widgets:         widget(s) to observe changes of their `pos` and `size` properties. if specified more
+                                than one widget then the pos/size coordinates of the rectangle that is enclosing all
+                                specified widgets are propagated.
+        :param bind_window_size: pass True to propagate pos and size changes if window size changes.
+        """
+        self.widgets = widgets
+        self.relatives: List[Widget] = list()
+        self.main_app = App.get_running_app().main_app
+
+        self._pos_attributes: List[PropagatedAttributes] = list()
+        self._size_attributes: List[PropagatedAttributes] = list()
+        self._pos_callbacks: List[PosSizeCallable] = list()
+        self._size_callbacks: List[PosSizeCallable] = list()
+        self._bound_wid_properties: List[BoundWidgetPropertyId] = list()
+        self._bound_rel_properties: List[BoundWidgetPropertyId] = list()
+
+        self._bind()
+        if bind_window_size:
+            uid = Window.fbind('size', self._rel_size_changed)
+            self._bound_rel_properties.append((Window, 'size', uid))
+
+    def _bind(self):
+        for wid in self.widgets:
+            uid = wid.fbind('pos', self._wid_pos_changed)
+            self._bound_wid_properties.append((wid, 'pos', uid))
+
+            uid = wid.fbind('size', self._wid_size_changed)
+            self._bound_wid_properties.append((wid, 'size', uid))
+
+            parent = wid.parent
+            while parent != parent.parent:
+                if isinstance(parent, (ScrollView, RelativeLayout)) and parent not in self.relatives:
+                    uid = parent.fbind('pos', self._rel_pos_changed)
+                    self._bound_rel_properties.append((parent, 'pos', uid))
+
+                    uid = parent.fbind('size', self._rel_size_changed)
+                    self._bound_rel_properties.append((parent, 'size', uid))
+
+                    self.relatives.append(parent)
+
+                parent = parent.parent
+
+    def _propagate(self, wid, value, attributes, callbacks):
+        self.main_app.vpo(f"AbsolutePosSizeBinder._propagate({wid}, {value}, {attributes}, {callbacks})")
+
+        for (target, attribute, converter) in attributes:
+            setattr(target, attribute, converter(wid, value) if converter else value)
+
+        for callback in callbacks:
+            callback(wid, value)
+
+    def _wid_pos_changed(self, wid: Widget, new_pos: List[float]):
+        """ propagate `pos` property change to target attributes and subscribed observers.
+
+        :param wid:             bound widget or a ScrollView that is embedding the bound widget, which pos changed.
+        :param new_pos:         new position of the bound widget/ScrollView (unused).
+        """
+        wgs = self.widgets
+        new_pos = self.main_app.widgets_enclosing_rectangle(wgs)[:2] if len(wgs) > 1 else wid.to_window(*new_pos)
+        self._propagate(wid, new_pos, self._pos_attributes, self._pos_callbacks)
+
+    def _wid_size_changed(self, wid: Widget, new_size: List[float]):
+        """ propagate `size` property change to target attributes and subscribed observers.
+
+        :param wid:             bound widget or a ScrollView that is embedding the bound widget, which pos changed.
+        :param new_size:        new position of the bound widget/ScrollView (unused).
+        """
+        wgs = self.widgets
+        if len(wgs) > 1:
+            new_size = self.main_app.widgets_enclosing_rectangle(wgs)[2:]
+        self._propagate(wid, new_size, self._size_attributes, self._size_callbacks)
+
+    def _rel_pos_changed(self, _rel: Widget, _new_pos: list):
+        """ propagate `pos` property change of relative/scrollable layout/container.
+
+        :param _rel:            relative layout or a scroll view, embedding bound widget(s), which pos changed.
+        :param _new_pos:        new position of the RelativeLayout/ScrollView (unused).
+        """
+        wid = self.widgets[0]
+        self._wid_pos_changed(wid, wid.pos)
+
+    def _rel_size_changed(self, _rel: Widget, _new_size: list):
+        """ propagate size change of relative/scrollable layout/container.
+
+        :param _rel:            relative layout or a scroll view, embedding bound widget(s), which size changed.
+        :param _new_size:       new size of the RelativeLayout/ScrollView (unused).
+        """
+        wid = self.widgets[0]
+        self._wid_size_changed(wid, wid.size)
+        self._wid_pos_changed(wid, wid.pos)     # layout size change mostly does change also the absolute widget pos
+
+    def pos_to_attribute(self, target: Any, attribute: str, converter: Optional[PosSizeCallable] = None):
+        """ request the propagation of the changed (absolute) widget(s) position to an object attribute.
+
+        :param target:          the object which attribute will be changed on change of `pos`.
+        :param attribute:       the name of the attribute to assign the new/changed absolute position.
+        :param converter:       optional pos value converter, return the finally value assigned to the attribute.
+        """
+        self._pos_attributes.append((target, attribute, converter))
+
+    def pos_to_callback(self, callback: PosSizeCallable):
+        """ bind callable to `pos` change event.
+
+        :param callback:        callable to be called when pos changed with the changed widget and pos as arguments.
+        """
+        self._pos_callbacks.append(callback)
+
+    def size_to_attribute(self, target: Any, attribute: str, converter: Optional[PosSizeCallable] = None):
+        """ request the propagation of the changed widget(s) size to an object attribute.
+
+        :param target:          the object which attribute will be changed on change of `size`.
+        :param attribute:       the name of the attribute to assign the new/changed size.
+        :param converter:       optional pos value converter, return the finally value assigned to the attribute.
+        """
+        self._size_attributes.append((target, attribute, converter))
+
+    def size_to_callback(self, callback: PosSizeCallable):
+        """ bind callable to `size` change event.
+
+        :param callback:        callable to be called when size changed with the changed widget and size as arguments.
+        """
+        self._size_callbacks.append(callback)
+
+    def unbind(self):
+        """ unbind the widget(s) of this binder instance.
+
+        .. note:: this instance can be destroyed after the call of this method. for new bindings create a new instance.
+        """
+        for (wid, prop, uid) in reversed(self._bound_rel_properties):
+            wid.unbind_uid(prop, uid)
+        self._bound_rel_properties.clear()
+
+        for (wid, prop, uid) in reversed(self._bound_wid_properties):
+            wid.unbind_uid(prop, uid)
+        self._bound_wid_properties.clear()
+
+        self.relatives = self._pos_attributes = self._size_attributes = self._pos_callbacks = self._size_callbacks = []
+        self.widgets = ()
+
+
+class ModalBehavior:                                                                                # pragma: no cover
     """ mix-in making a container widget modal. """
     # abstracts provided by the mixing-in container widget
     center: List
@@ -256,9 +408,104 @@ class ModalBehavior:
         return True
 
 
-class HelpBehavior:
-    """ behaviour mixin class for widgets providing help texts.
+class Tooltip(ScrollView):                                                           # pragma: no cover
+    """ semi-transparent and optional click-through container to display help and tour page texts. """
+    targeted_widget = ObjectProperty()
+    """ target widget to display tooltip text for (mostly a button, but could any, e.g. a layout widget).
+
+    :attr:`targeted_widget` is a :class:`~kivy.properties.ObjectProperty` and defaults to the main app help_activator.
     """
+
+    tip_text = StringProperty()
+    """ tooltip text string to display.
+
+    :attr:`tip_text` is a :class:`~kivy.properties.StringProperty` and defaults to an empty string.
+    """
+
+    anchor_spe = ObjectProperty()       #: anchor pos and direction, see :data:`~ae.gui_help.AnchorSpecType` (read-only)
+    has_tour = BooleanProperty(False)   #: True if a tour exists for the current app flow/help context (read-only)
+    tap_thru = BooleanProperty(False)   #: True if user can tap widgets behind/covered by this tooltip win (read-only)
+    tour_start_pos = ListProperty()     #: screen position of the optionally displayed tour start button (read-only)
+    tour_start_size = ListProperty()    #: size of the optionally displayed tour start button (read-only)
+
+    def __init__(self, **kwargs):
+        self.main_app = App.get_running_app().main_app
+        self.targeted_widget = self.main_app.help_activator     # set default-value before calling super()
+
+        super().__init__(**kwargs)
+
+        self._targeted_binder = AbsolutePosSizeBinder(self.targeted_widget)
+        self._actual_pos()                                      # init self.anchor_spe
+
+    def _actual_pos(self, *_args) -> Tuple[float, float]:
+        wid = self.targeted_widget
+        win_w, win_h = Window.size
+        self.anchor_spe = anc = anchor_spec(*wid.to_window(*wid.pos), *wid.size, win_w, win_h)
+        return anchor_layout_x(anc, self.width, win_w), anchor_layout_y(anc, self.height, win_h)
+
+    def collide_tap_thru_toggler(self, touch_x: float, touch_y: float) -> bool:
+        """ check if touch is on the tap thru toggler pseudo button.
+
+        :param touch_x:         window x position of touch.
+        :param touch_y:         window y position of touch.
+        :return:                True if user touched the tap through toggler.
+        """
+        anchor_pts = anchor_points(self.main_app.font_size, self.anchor_spe)
+
+        x_values = tuple(x for idx, x in enumerate(anchor_pts) if not idx % 2)
+        min_x, max_x = min(x_values), max(x_values)
+        y_values = tuple(x for idx, x in enumerate(anchor_pts) if idx % 2)
+        min_y, max_y = min(y_values), max(y_values)
+
+        return min_x <= touch_x < max_x and min_y <= touch_y < max_y
+
+    def collide_tour_start_button(self, touch_x: float, touch_y: float) -> bool:
+        """ check if touch is on the tap thru toggler pseudo button.
+
+        :param touch_x:         window x position of touch.
+        :param touch_y:         window y position of touch.
+        :return:                True if user touched the tap thru toggler.
+        """
+        min_x, min_y = self.tour_start_pos
+        width, height = self.tour_start_size
+        max_x, max_y = min_x + width, min_y + height
+
+        return min_x <= touch_x < max_x and min_y <= touch_y < max_y
+
+    def on_targeted_widget(self, *_args):
+        """ targeted widget changed event handler.
+
+        :param _args:           change event args (unused).
+        """
+        self._targeted_binder.unbind()
+
+        wid = self.targeted_widget
+        self._targeted_binder = twb = AbsolutePosSizeBinder(wid, bind_window_size=True)
+        twb.size_to_attribute(self, 'pos', self._actual_pos)
+        twb.pos_to_attribute(self, 'pos', self._actual_pos)
+
+    def on_touch_down(self, touch: MotionEvent) -> bool:
+        """ check for additional events added by this class.
+
+        :param touch:           motion/touch event data.
+        :return:                True if event got processed/used.
+        """
+        if self.collide_tap_thru_toggler(*touch.pos):
+            self.tap_thru = not self.tap_thru
+            ret = True
+        elif self.has_tour and self.collide_tour_start_button(*touch.pos):
+            ret = self.main_app.start_app_tour(help_id_tour_class(self.targeted_widget.help_id))
+        elif self.tap_thru or not self.collide_point(*touch.pos):
+            ret = False     # if self.tap_thru then make this tooltip widget transparent and let user click through
+        else:
+            ret = super().on_touch_down(touch)
+        return ret
+
+
+# ============================   help system   ========================================================================
+
+class HelpBehavior:
+    """ behaviour mixin class for widgets providing help texts. """
     help_id = StringProperty()
     """ unique help id of the widget.
 
@@ -307,75 +554,6 @@ class HelpBehavior:
         return super().on_touch_down(touch)                 # type: ignore # pylint: disable=no-member # false positive
 
 
-class Tooltip(ScrollView):                                                           # pragma: no cover
-    """ semi-transparent and optional click-through container to display help and tour page texts. """
-    explained_widget = ObjectProperty()
-    """ target widget to display tooltip text for (mostly a button, but could any, e.g. a layout widget).
-
-    :attr:`explained_widget` is a :class:`~kivy.properties.ObjectProperty` and defaults to None.
-    """
-
-    tip_text = StringProperty()
-    """ tooltip text string to display.
-
-    :attr:`tip_text` is a :class:`~kivy.properties.StringProperty` and defaults to an empty string.
-    """
-
-    explained_pos = ListProperty()      #: Window position of the explained widget
-    has_tour = BooleanProperty(False)   #: True if a tour exists for the current app flow/help context (read-only)
-    ps_hints = ObjectProperty()         #: pos- and size-hints for the layout window widget (read-only)
-    tap_thru = BooleanProperty(False)   #: True if user can tap widgets behind/covered by this tooltip win (read-only)
-    tour_start_pos = ListProperty()     #: screen position of the optionally displayed tour start button (read-only)
-    tour_start_size = ListProperty()    #: size of the optionally displayed tour start button (read-only)
-
-    def collide_tap_thru_toggler(self, touch_x: float, touch_y: float) -> bool:
-        """ check if touch is on the tap thru toggler pseudo button.
-
-        :param touch_x:         window x position of touch.
-        :param touch_y:         window y position of touch.
-        :return:                True if user touched the tap through toggler.
-        """
-        anchor_pts = anchor_points(App.get_running_app().main_app.font_size, self.ps_hints)
-
-        x_values = tuple(x for idx, x in enumerate(anchor_pts) if not idx % 2)
-        min_x, max_x = min(x_values), max(x_values)
-        y_values = tuple(x for idx, x in enumerate(anchor_pts) if idx % 2)
-        min_y, max_y = min(y_values), max(y_values)
-
-        return min_x <= touch_x < max_x and min_y <= touch_y < max_y
-
-    def collide_tour_start_button(self, touch_x: float, touch_y: float) -> bool:
-        """ check if touch is on the tap thru toggler pseudo button.
-
-        :param touch_x:         window x position of touch.
-        :param touch_y:         window y position of touch.
-        :return:                True if user touched the tap thru toggler.
-        """
-        min_x, min_y = self.tour_start_pos
-        width, height = self.tour_start_size
-        max_x, max_y = min_x + width, min_y + height
-
-        return min_x <= touch_x < max_x and min_y <= touch_y < max_y
-
-    def on_touch_down(self, touch: MotionEvent) -> bool:
-        """ check for additional events added by this class.
-
-        :param touch:           motion/touch event data.
-        :return:                True if event got processed/used.
-        """
-        app = App.get_running_app()
-        if self.collide_tap_thru_toggler(*touch.pos):
-            self.tap_thru = not self.tap_thru
-            ret = True
-        elif self.has_tour and self.collide_tour_start_button(*touch.pos):
-            ret = app.main_app.start_app_tour(help_id_tour_class(self.explained_widget.help_id))
-        elif self.tap_thru or not self.collide_point(*touch.pos):
-            ret = False     # if self.tap_thru then make this tooltip widget transparent and let user click through
-        else:
-            ret = super().on_touch_down(touch)
-        return ret
-
-
 class HelpToggler(ReliefCanvas, Image):                                                               # pragma: no cover
     """ widget to activate and deactivate the help mode.
 
@@ -388,7 +566,8 @@ class HelpToggler(ReliefCanvas, Image):
     """
     def __init__(self, **kwargs):
         """ initialize an instance of this class and also :attr:`~ae.gui_help.HelpAppBase.help_activator`. """
-        App.get_running_app().main_app.help_activator = self
+        self.main_app = App.get_running_app().main_app
+        self.main_app.help_activator = self
         super().__init__(**kwargs)
 
     def on_touch_down(self, touch: MotionEvent) -> bool:
@@ -398,11 +577,14 @@ class HelpToggler(ReliefCanvas, Image):
         :return:                True if touch happened on this button (and will get no further processed => eaten).
         """
         if self.collide_point(*touch.pos):
-            App.get_running_app().main_app.help_activation_toggle()
+            self.main_app.help_activation_toggle()
             return True
         return False
 
 
+# ============================   app tours   ==========================================================================
+
+
 PageAnimationType = Tuple[str, Union[Animation, str]]
 """ tuple of a widget id string and an :class:`~kivy.animation.Animation` instance/evaluation-expression.
 
@@ -464,6 +646,7 @@ class AnimatedTourMixin:        # (TourBase):
 
         self._added_animations: List[Tuple[Widget, Animation, WidgetValues]] = list()
         self._added_shaders: List[Tuple[Widget, ShaderIdType]] = list()
+        self._explained_binder = AbsolutePosSizeBinder()
 
         self.pages_animations: Dict[Optional[str], PageAnimationsType] = dict()
         """ dict of compound animation instances of the pages of this tour.
@@ -539,13 +722,34 @@ class AnimatedTourMixin:        # (TourBase):
             # noinspection PyUnresolvedReferences
             super().next_page()                                                             # pylint: disable=no-member
 
+    def setup_explained_widget(self) -> list:
+        """ overridden to bind pos/size of explained widget(s) to the tour layout/overlay placeholder.
+
+        :return:                list of explained widget instances.
+        """
+        self._explained_binder.unbind()
+
+        # noinspection PyUnresolvedReferences
+        widgets = super().setup_explained_widget()                          # type: ignore # pylint: disable=no-member
+
+        layout = self.layout
+        exp_wid = layout.explained_widget
+        self._explained_binder = ebi = AbsolutePosSizeBinder(*widgets, bind_window_size=True)
+        ebi.size_to_attribute(layout, 'explained_size')
+        ebi.pos_to_attribute(layout, 'explained_pos')
+        if exp_wid is layout.ids.explained_placeholder:
+            ebi.size_to_attribute(exp_wid, 'size')
+            ebi.pos_to_attribute(exp_wid, 'pos')
+
+        return widgets
+
     def setup_page_shaders_and_animations(self):
         """ setup shaders and animations of the current page.
 
         specified in :attr:`~AnimatedTourMixin.pages_shaders` and :attr:`~AnimatedTourMixin.pages_animations`.
         """
         def _evaluated_shader_kwargs() -> dict:
-            tour_shader_kwargs = deepcopy(shader_kwargs)
+            tour_shader_kwargs = deepcopy(shader_kwargs)    # pylint: disable=undefined-loop-variable
             glo_vars = self.main_app.global_variables(layout=layout, sp=sp, tour=self, Clock=Clock, Window=Window)
             for key, arg in tour_shader_kwargs.items():
                 if isinstance(arg, str) and key not in ('add_to', 'render_shape', 'shader_code', 'shader_file'):
@@ -592,14 +796,14 @@ class AnimatedTourMixin:        # (TourBase):
                 self.main_app.call_method_delayed(next_delay, self.simulate_text_input, text_input, text_to_delay[1:],
                                                   text_to_insert=text_to_delay[0], deltas=deltas[1:] + (next_delay, ))
 
-    def tap_animation(self, wid_id: str = '', position_delay: float = 2.34,
+    def tap_animation(self, wid_id: str = '', pos_delay: float = 2.34,
                       press_delay: float = 0.69, release_delay: float = 0.39) -> PageAnimationType:
         """ create an compound animation instance simulating a user touch/tap on the widget with the passed widget id.
 
         :param wid_id:          specifies the widget to be tap simulated: either a widget id string (first item of the
                                 :data:`PageAnimationType` tuple), or (if prefixed with a column character) tap/focus/
                                 state id of a widget, or an empty string (specifies the currently explained widget).
-        :param position_delay:  time in seconds to move the pointer from the next button to the widget.
+        :param pos_delay:       time in seconds to position/move the pointer from the next button to the widget.
         :param press_delay:     time in seconds of the button press simulation animation.
         :param release_delay:   time in seconds of the button release simulation animation.
         :return:                compound animation instance simulating a tap.
@@ -614,25 +818,29 @@ class AnimatedTourMixin:        # (TourBase):
         tap_wid_x, tap_wid_y = tap_wid.to_window(*tap_wid.center)
         nxt_wid = layout.ids.next_but
         poi_wid = layout.ids.tap_pointer
-        poi_width, poi_height = poi_wid.size
-        poi_x = tap_wid_x - poi_width * 13.0 / 30.0    # - tap_pointer.png index finger x position offset
-        poi_y = tap_wid_y - poi_height * 29.0 / 30.0
+        poi_w, poi_h = poi_wid.size
+        poi_x = tap_wid_x - poi_w * 13.0 / 30.0    # - tap_pointer.png index finger x position offset
+        poi_y = tap_wid_y - poi_h * 29.0 / 30.0
 
         poi_wid.center = nxt_wid.center
-        press_ani = Animation(x=poi_x + poi_width * 0.156, y=poi_y + poi_height * 0.153,
-                              width=poi_width * 0.69, height=poi_height * 0.69, d=press_delay, t='out_sine')
-        ani = Animation(x=poi_x, y=poi_y, opacity=1.0, d=position_delay, t='in_sine') \
-            + press_ani \
-            + Animation(x=poi_x, y=poi_y, width=poi_width, height=poi_height, opacity=0.39, d=release_delay - 0.03)
+        ani = Animation(x=poi_x, y=poi_y, width=poi_w, height=poi_h, opacity=1.0, d=pos_delay, t='in_sine') \
+            + Animation(x=poi_x + poi_w * 0.156, y=poi_y + poi_h * 0.153,
+                        width=poi_w * 0.69, height=poi_h * 0.69, d=press_delay, t='out_sine')
+        poi_values = animated_widget_values(poi_wid, ani)
 
         if isinstance(tap_wid, ButtonBehavior):
+            release_ani = Animation(x=poi_x, y=poi_y, width=poi_w, height=poi_h, opacity=0.39, d=release_delay - 0.03)
+
             def _touched_anim():
                 wid_state = tap_wid.state
                 tap_wid.state = 'normal' if wid_state == 'down' else 'down'
                 if not isinstance(tap_wid, ToggleButtonBehavior):
+                    release_ani.start(poi_wid)
                     self.main_app.call_method_delayed(
                         release_delay, lambda *_args: (setattr(tap_wid, 'state', wid_state), self.setup_texts()))
-            press_ani.bind(on_complete=lambda *_args: (_touched_anim(), self.setup_texts()))
+
+            ani.bind(on_complete=lambda *_args: (_touched_anim(), self.setup_texts()))
+            release_ani.bind(on_complete=lambda *_args: restore_widget_values(poi_wid, poi_values))
 
         return ani
 
@@ -835,11 +1043,17 @@ class TourOverlay(ModalBehavior, ShadersMixin, FloatLayout):
     """
 
     explained_pos = ListProperty([-9, -9])
-    """ window position of the target/explained widget.
+    """ window position (absolute x, y window coordinates) of the targeted/explained/highlighted widget.
 
     :attr:`explained_pos` is a :class:`~kivy.properties.ListProperty` and is read-only.
     """
 
+    explained_size = ListProperty([0, 0])
+    """ widget size (width, height) of the targeted/explained/highlighted widget.
+
+    :attr:`explained_size` is a :class:`~kivy.properties.ListProperty` and is read-only.
+    """
+
     explained_widget = ObjectProperty()
     """ explained widget instance on actual tour (page).
 
@@ -893,14 +1107,13 @@ class TourOverlay(ModalBehavior, ShadersMixin, FloatLayout):
 
     def page_updated(self):
         """ callback from :meth:`~TourBase.setup_layout` for UI-specific patches, after tour layout/overlay setup. """
-        Clock.tick()                        # let Kivy fully update the layout (e.g. for tour_page_texts.height)
         tooltip = self.ids.tooltip
         win_height = Window.height
         nav_y = self.label_height * 1.29    # default pos_y of navigation bar with prev/next buttons
         if self.main_app.widget_visible(tooltip):
             exp_y = self.explained_pos[1]
             pos1 = min(exp_y, tooltip.y)
-            pos2 = max(exp_y + self.explained_widget.height, tooltip.top)
+            pos2 = max(exp_y + self.explained_size[1], tooltip.top)
             if pos1 < win_height - pos2:
                 nav_y = max(nav_y + pos2, win_height - self.ids.tour_page_texts.height)
         Animation(navigation_pos_hint_y=nav_y / win_height, t='in_out_sine', d=3).start(self)
